/*
 * Copyright (c) 2017. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.compare;

import java.io.Serializable;
import java.util.Comparator;

import org.hedgecode.snooker.api.Player;

/**
 * Set of Comparators for {@link Player}.
 * 1. Sorting by Last Name of Player {@link NameComparator};
 * 2. Sorting by Age of Player {@link AgeComparator}.
 *
 * @author Dmitry Samoshin aka gotty
 */
public enum PlayerComparators {

    NAME ( new NameComparator() ),
    AGE  ( new AgeComparator() );

    private Comparator<Player> comparator;

    PlayerComparators(Comparator<Player> comparator) {
        this.comparator = comparator;
    }

    public Comparator<Player> comparator() {
        return comparator;
    }

    static class NameComparator implements Comparator<Player>, Serializable {

        @Override
        public int compare(Player player1, Player player2) {
            return player1.lastName().compareTo(player2.lastName());
        }

    }

    static class AgeComparator implements Comparator<Player>, Serializable {

        @Override
        public int compare(Player player1, Player player2) {
            return player1.born().compareTo(player2.born());
        }

    }

}
